==> cgop-common-cache-start-1.0.8-sources.jar: com/efuture/ocp/common/distributedLock/DistributedLockAspect.java <==
package com.efuture.ocp.common.distributedLock;

import com.efuture.common.utils.ServiceLogs;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockCacheException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockGetKeyException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockIsExistException;
import com.efuture.ocp.common.exception.ResponseCode;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Aspect
@Component
public class DistributedLockAspect
{

    @Autowired
    DistributedLockHandle lockHandle;

    @Autowired
    DistributedLockKeyHandle keyHandle;

    @Around("@annotation(around)")
    public Object round(ProceedingJoinPoint point, DLock around) throws Throwable
    {
        ServiceLogs.truedebuglog("DistributedLock", "开始执行", 0);
        String lockKey = "";

        try {
            lockKey = keyHandle.getKey(point, around);
        }
        catch (Exception e) {
            ServiceLogs.errLog("DistributedLock", e, "获取锁的key失败");
            throw new DistributedLockGetKeyException(ResponseCode.EXCEPTION, "获取锁的key失败[{0}]", e.getMessage());
        }

        ServiceLogs.truedebuglog("DistributedLock", "获取到Key:" + lockKey, 0);
        int lockExpire = around.lockExpire();
        DLockInfo lock = null;

        try {
            lock = lockHandle.tryLock(lockKey, lockExpire, around.waitMillSeconds());
        }
        catch (Exception e) {
            ServiceLogs.errLog("DistributedLock", e, "获取锁失败[{0}]");
            throw new DistributedLockCacheException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
        }

        if (lock == null) {
            throw new DistributedLockIsExistException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
        }

        Object result = null;

        try {
            result = point.proceed();
        }
        catch (Throwable e) {
            //lockHandle.unlock(lockKey, lockExpire);
            throw e;
        }
        finally {
            lockHandle.unlock(lock);
        }

        return result;
    }
}

==> cgop-common-cache-start-1.0.16-sources.jar: com/efuture/ocp/common/distributedLock/DistributedLockAspect.java <==
package com.efuture.ocp.common.distributedLock;

import com.efuture.common.utils.ServiceLogs;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockCacheException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockGetKeyException;
import com.efuture.ocp.common.distributedLock.exception.DistributedLockIsExistException;
import com.efuture.ocp.common.exception.ResponseCode;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Aspect
@Component
public class DistributedLockAspect
{

    @Autowired
    DistributedLockHandle lockHandle;

    @Autowired
    DistributedLockKeyHandle keyHandle;

    @Around("@annotation(around)")
    public Object round(ProceedingJoinPoint point, DLock around) throws Throwable
    {
        ServiceLogs.debug("DistributedLock", "开始执行", 0);
        String lockKey = "";

        try {
            lockKey = keyHandle.getKey(point, around);
        }
        catch (Exception e) {
            ServiceLogs.error("DistributedLock", e, "获取锁的key失败", 0);
            throw new DistributedLockGetKeyException(ResponseCode.EXCEPTION, "获取锁的key失败[{0}]", e.getMessage());
        }

        ServiceLogs.debug("DistributedLock", "获取到Key:" + lockKey, 0);
        int lockExpire = around.lockExpire();
        DLockInfo lock = null;

        try {
            lock = lockHandle.tryLock(lockKey, lockExpire, around.waitMillSeconds());
        }
        catch (Exception e) {
            ServiceLogs.error("DistributedLock", e, "获取锁失败[{0}]", 0);
            throw new DistributedLockCacheException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
        }

        if (lock == null) {
            throw new DistributedLockIsExistException(ResponseCode.EXCEPTION, "获取锁失败[{0}]", lockKey);
        }

        Object result = null;

        try {
            result = point.proceed();
        }
        catch (Throwable e) {
            //lockHandle.unlock(lockKey, lockExpire);
            throw e;
        }
        finally {
            lockHandle.unlock(lock);
        }

        return result;
    }
}
